///#include "main.h"
#include <time.h>
#include "renderer.h"
#include "sound.h"
#include "screen.h"
#include "pad.h"
#include "menu.h"

int pad_state;
int cur_time;
int now_sensor_x,now_sensor_y;
int bMenu=0;

const char *scr_names[] = {
	//"x1",
	"x2",
	"x3",
};

void render_screen(void *buf)
{
	if(setting.screensize==0){
		if (border_uploaded && sgb_mode){
			pgBitBltSgb((screen_w - SGBWIDTH*2)/2,
				(screen_h - SGBHEIGHT*2)/2, sgb_border_buffer);
		}
		pgBitBltN2((screen_w - GBWIDTH*2)/2,
			(screen_h - GBHEIGHT*2)/2,(u16*)buf);
	}
	else if(setting.screensize==1){
		pgBitBltN3((screen_w - GBWIDTH*3)/2,
			(screen_h - GBHEIGHT*3)/2,(u16*)buf);
	}
}

void renderer_update_sound()
{
	static unsigned int nextbank=1;
	unsigned int playbank=cur_play/SOUND_BANKLEN;
	if (nextbank!=playbank) {
		snd_render(&sound_buf[nextbank*SOUND_BANKLEN/2],SOUND_BANKLEN/4);
		nextbank=((nextbank+1)&3);
	}
}

#define UPPER_THRESHOLD  0xcf
#define LOWER_THRESHOLD  0x2f
void renderer_update_pad()
{
	readpad();
	pad_state=0;
	if(pad[0].button & PAD_BUTTON_A)
		pad_state|=1;
	if(pad[0].button & PAD_BUTTON_B)
		pad_state|=2;
	if(pad[0].button & PAD_TRIGGER_Z)
		pad_state|=4;
	if(pad[0].button & PAD_BUTTON_START)
		pad_state|=8;
	
	if(pad[0].button & PAD_BUTTON_DOWN || pad[0].stickY < -65)
		pad_state|=16;
	if(pad[0].button & PAD_BUTTON_UP || pad[0].stickY > 65)
		pad_state|=32;
	if(pad[0].button & PAD_BUTTON_LEFT || pad[0].stickX < -65)
		pad_state|=64;
	if(pad[0].button & PAD_BUTTON_RIGHT || pad[0].stickX > 65)
		pad_state|=128;
	
	if(new_pad & PAD_TRIGGER_L)
		bMenu = 1;
	if(new_pad & PAD_TRIGGER_R){
		setting.screensize = (setting.screensize+1)%2;
		VIDEO_ClearFrameBuffer (vmode, xfb[0], COLOR_BLACK);
		VIDEO_ClearFrameBuffer (vmode, xfb[1], COLOR_BLACK);
	}
}

void renderer_refresh()
{
	renderer_update_pad();
	renderer_update_sound();
}

void renderer_init()
{
	cur_time=0;	
	renderer_reset();
}

void renderer_reset()
{
	pad_state=0;
	now_sensor_x=now_sensor_y=2047;
}

byte renderer_get_time(int type)
{
	unsigned long now=time(NULL)-cur_time;

	switch(type){
	case 8: // b
		return (byte)(now%60);
	case 9: // 
		return (byte)((now/60)%60);
	case 10: // 
		return (byte)((now/(60*60))%24);
	case 11: // (L)
		return (byte)((now/(24*60*60))&0xff);
	case 12: // (H)
		return (byte)((now/(256*24*60*60))&1);
	}
	return 0;
}

void renderer_set_time(int type,byte dat)
{
	unsigned long now=time(NULL);
	unsigned long adj=now-cur_time;

	switch(type){
	case 8: // b
		adj=(adj/60)*60+(dat%60);
		break;
	case 9: // 
		adj=(adj/(60*60))*60*60+(dat%60)*60+(adj%60);
		break;
	case 10: // 
		adj=(adj/(24*60*60))*24*60*60+(dat%24)*60*60+(adj%(60*60));
		break;
	case 11: // (L)
		adj=(adj/(256*24*60*60))*256*24*60*60+(dat*24*60*60)+(adj%(24*60*60));
		break;
	case 12: // (H)
		adj=(dat&1)*256*24*60*60+(adj%(256*24*60*60));
		break;
	}
	cur_time=now-adj;
}

void renderer_set_bibrate(BOOL bibrate)
{
}

word renderer_get_sensor(BOOL x_y)
{
	return (x_y?(now_sensor_x&0x0fff):(now_sensor_y&0x0fff));
}

int renderer_get_timer_state()
{
	return cur_time;
}

void renderer_set_timer_state(int timer)
{
	cur_time=timer;
}
